@@ -1,11 +1,15 @@
 static const Bool wmborder = True;
 static int fontsize = 22;
-static double overlay_delay = 1.0; //in seconds
-static double repeat_delay = 0.75; //in seconds, will not work on keys with overlays
-static int scan_rate = 50; //scan rate in microseconds, affects key repetition rate
-static int heightfactor = 14; //one row of keys takes up 1/x of the screen height
-static int xspacing = 5;
-static int yspacing = 5;
+/* overlay delay in seconds */
+static double overlay_delay = 1.0;
+/* repeat delay in seconds, will not work on keys with overlays */
+static double repeat_delay = 0.75;
+/* scan rate in microseconds, affects key repetition rate */
+static int scan_rate = 50;
+/* one row of keys takes up 1/x of the screen height */
+static int heightfactor = 14;
+static int xspacing = 1;
+static int yspacing = 1;
 static const char *defaultfonts[] = {
 	"DejaVu Sans:bold:size=22"
 };
