@@ -453,7 +453,7 @@ press(Key *k, KeySym buttonmod)
 		if (enableoverlays && currentoverlay == -1)
 			overlayidx = hasoverlay(k->keysym);
 		if ((pressonrelease) || (enableoverlays && overlayidx != -1)) {
-			/*record the begin of the press, don't simulate the actual keypress yet */
+			/* record the begin of the press, don't simulate the actual keypress yet */
 			record_press_begin(k->keysym);
 		} else {
 			printdbg("Simulating press: %ld (mod %ld)\n", k->keysym, buttonmod);
@@ -481,9 +481,18 @@ press(Key *k, KeySym buttonmod)
 int
 tmp_remap(KeySym keysym)
 {
-	XChangeKeyboardMapping(dpy, tmp_keycode, 1, &keysym, 1);
+	/* map lower and upper case of keysym to the temporary keycode */
+	KeySym syms[2];
+	XConvertCase(keysym, &syms[0], &syms[1]);
+
+	/* if keysym is capital letter then swap upper and lower case */
+	if (keysym == syms[1])
+		syms[1] = syms[0], syms[0] = keysym;
+
+	XChangeKeyboardMapping(dpy, tmp_keycode, syms[0] == syms[1] ? 1 : 2, syms, 1);
 	XSync(dpy, False);
 
+	printdbg("Temporary map keysym %ld (%ld, %ld) to keycode %d\n", keysym, syms[0], syms[1], tmp_keycode);
 	return tmp_keycode;
 }
 
@@ -752,10 +761,10 @@ readxresources(void)
 		if (XrmGetResource(xdb, "svkbd.ABCbackground", "*", &type, &xval) && !colors[SchemeNormABC][ColBg])
 			colors[SchemeNormABC][ColBg] = estrdup(xval.addr);
 
-		if (XrmGetResource(xdb, "svkbd.ABCshiftforeground", "*", &type, &xval) && !colors[SchemeNormShift][ColFg])
-			colors[SchemeNormShift][ColFg] = estrdup(xval.addr);
-		if (XrmGetResource(xdb, "svkbd.ABCshiftbackground", "*", &type, &xval) && !colors[SchemeNormShift][ColBg])
-			colors[SchemeNormShift][ColBg] = estrdup(xval.addr);
+		if (XrmGetResource(xdb, "svkbd.ABCshiftforeground", "*", &type, &xval) && !colors[SchemeNormABCShift][ColFg])
+			colors[SchemeNormABCShift][ColFg] = estrdup(xval.addr);
+		if (XrmGetResource(xdb, "svkbd.ABCshiftbackground", "*", &type, &xval) && !colors[SchemeNormABCShift][ColBg])
+			colors[SchemeNormABCShift][ColBg] = estrdup(xval.addr);
 
 		if (XrmGetResource(xdb, "svkbd.pressbackground", "*", &type, &xval) && !colors[SchemePress][ColBg])
 			colors[SchemePress][ColBg] = estrdup(xval.addr);
